@@ -24,12 +24,14 @@ lapply(
     mu <- list(
       c(5.76, 5.18)
     )
-    phi <- list(
-      -0.1 * diag(p),
-      -0.2 * diag(p),
-      -0.3 * diag(p),
-      -0.4 * diag(p),
-      -0.5 * diag(p)
+    phi <- SimPhiN(
+      n = 5,
+      phi = -0.1 * diag(p),
+      vcov_phi_vec_l = t(
+        chol(
+          0.1 * diag(p^2)
+        )
+      )
     )
     sigma <- matrix(
       data = c(
